@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#  Copyright (C) 2009, 2010, 2012 Rocky Bernstein
+#  Copyright (C) 2009-2010, 2012-2013 Rocky Bernstein
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -24,6 +24,10 @@ NotImplementedMessage = "This method must be overriden in a subclass"
 
 import columnize
 from pygments.console import colorize
+from import_relative import import_relative
+Mformat = import_relative('format',  '...lib', 'pydbgr')
+
+__all__ = ['DebuggerCommand']
 
 class DebuggerCommand:
     """Base Class for Debugger commands. We pull in some helper
@@ -94,6 +98,13 @@ class DebuggerCommand:
             pass
         return None
         
+    def rst_msg(self, text, opts={}):
+        """Convert ReStructuredText and run through msg()"""
+        text = Mformat.rst_text(text,
+                                'plain' == self.debugger.settings['highlight'],
+                                self.debugger.settings['width'])
+        return self.msg(text)
+               
     def run(self, args):
         """ The method that implements the debugger command.
         Help on the command comes from the docstring of this method.
@@ -103,7 +114,7 @@ class DebuggerCommand:
     pass
 
     def section(self, message, opts={}):
-        if 'terminal' == self.settings['highlight']:
+        if 'plain' != self.settings['highlight']:
             message = colorize('bold', message)
             pass
         self.msg(message)
