@@ -6,8 +6,8 @@ from import_relative import *
 import_relative('io', '...pydbgr', 'pydbgr')
 Mserver   = import_relative('io.tcpserver', '...pydbgr', 'pydbgr')
 Mclient   = import_relative('io.tcpclient', '...pydbgr', 'pydbgr')
-import_relative('interface', '...pydbgr', 'pydbgr')
-Mcomcodes = import_relative('interface.comcodes', '...pydbgr', 'pydbgr')
+import_relative('interfaces', '...pydbgr', 'pydbgr')
+Mcomcodes = import_relative('interfaces.comcodes', '...pydbgr', 'pydbgr')
 
 class TestTCP(unittest.TestCase):
     """Tests TCPServer and TCPClient"""
